<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

if ( ! function_exists( 'mega_tour_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Mega Tour Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'mega_tour_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_tour_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Mega Tour Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'mega_tour_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_tour_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mega Tour Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mega_tour_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_tour_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Mega Tour Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Check if Business Design Enable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_third_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('third-design' == $home_layout )  ;
}


/**
 * Front Page Active Callbacks
 */


/**
 * Check if Top bar section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[topbar_section_enable]' )->value() );
}


/**
 * Check if slider panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}

/**
 * Check if slider section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if Slider section content type is trip.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}
/**
 * Check if Slider section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if Slider section content type is destination.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Slider section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[slider_content_type]' )->value();
	return mega_tour_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if Slider video btn and link.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_btn_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return (mega_tour_pro_is_slider_section_enable( $control ) && ($home_layout !='fourth-design'));
}

/**
 * Check if Slider video btn and link.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_slider_video_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return (mega_tour_pro_is_slider_section_enable( $control ) && in_array($home_layout,array('default-design','second-design')));
}

/**
 * Check if featured panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}

/**
 * Check if featured section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section image enable.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_image_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	$cat_meta_img = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_cat_meta_image_enable]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( ( 'category' == $content_type ) || ( ! $cat_meta_img ) );
}

/**
 * Check if featured cat meta image section enable.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_cat_meta_section_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( 'category' != $content_type );
}
/**
 * Check if featured section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured section content type is destination.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_featured_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[featured_content_type]' )->value();
	return mega_tour_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if popular destination panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}
/**
 * Check if popular destination section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]' )->value();
	return mega_tour_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}
/**
 * Check if about panel 
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ($home_layout != 'fourth-design')  ;
}
/**
 * Check if about section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[about_content_type]' )->value();
	return mega_tour_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[about_content_type]' )->value();
	return mega_tour_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if about panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_video_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return (mega_tour_pro_is_about_section_enable($control) && in_array($home_layout,array('default-design','second-design')))  ;
}

/**
 * Check if about section content type is trip.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[about_content_type]' )->value();
	return mega_tour_pro_is_about_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[about_content_type]' )->value();
	return mega_tour_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section counter content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_counter_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[about_section_counter_enable]' )->value() && mega_tour_pro_is_about_section_enable($control) );
	
}
/**
 * Check if about section wp travel is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_about_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[about_content_type]' )->value();
	return mega_tour_pro_is_about_section_enable( $control ) && class_exists( 'WP_Travel' );
}


/**
 * Check if package panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}

/**
 * Check if package section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[package_section_enable]' )->value() );
}
/**
 * Check if package section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if package section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if package section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[package_content_type]' )->value();
	return mega_tour_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[service_section_enable]' )->value() );
}
/**
 * Check if trip section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_trip_search_enable( $control ) {
	return ( class_exists( 'WP_Travel' ) && mega_tour_pro_is_service_section_enable($control) );
}
/**
 * Check if trip search title is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_trip_search_title_enable( $control ) {
	return ( mega_tour_pro_is_trip_search_enable($control) && $control->manager->get_setting( 'mega_tour_pro_theme_options[trip_search_enable]' )->value() );
}

/**
 * Check if service panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ($home_layout != 'fourth-design')  ;
}

/**
 * Check if service btn  Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_btn_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ( mega_tour_pro_is_service_section_enable($control) && in_array($home_layout,array('default-design','second-design')) )  ;
}

/**
 * Check if service section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'trip-types' == $content_type );
}
/**
 * Check if service section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if service section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[service_content_type]' )->value();
	return mega_tour_pro_is_service_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if Business service section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_service_business_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[service_section_enable]' )->value() && ($home_layout == 'third-design'));
}

/**
 * Check if team panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('third-design' == $home_layout )  ;
}

/**
 * Check if team section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[team_content_type]' )->value();
	return mega_tour_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[team_content_type]' )->value();
	return mega_tour_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[team_content_type]' )->value();
	return mega_tour_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[team_content_type]' )->value();
	return mega_tour_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section content type is author.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_team_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[team_content_type]' )->value();
	return mega_tour_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}
/**
 * Check if gallery panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}
/**
 * Check if gallery section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[gallery_content_type]' )->value();
	return mega_tour_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if gallery section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[gallery_content_type]' )->value();
	return mega_tour_pro_is_gallery_section_enable( $control ) && ( 'trip-types' == $content_type );
}
/**
 * Check if gallery section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[gallery_content_type]' )->value();
	return mega_tour_pro_is_gallery_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if gallery section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_gallery_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[gallery_content_type]' )->value();
	return mega_tour_pro_is_gallery_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_section_enable]' )->value());
}
/**
 * Check if blog section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_default_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ( mega_tour_pro_is_blog_section_enable($control) && in_array($home_layout, array('default-design','second-design')));
}

/**
 * Check if  Blog Design Social section enable.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( $home_layout == 'fourth-design');
}
/**
 * Check if blog section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_title_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ( mega_tour_pro_is_blog_section_enable($control) && ($home_layout != 'fourth-design'));
}

/**
 * Check if blog section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_business_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ( mega_tour_pro_is_blog_section_enable($control) && ($home_layout== 'third-design'));
}

/**
 * Check if blog section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type ) ;
}

/**
 * Check if blog section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'trip-types' == $content_type );
}
/**
 * Check if blog section content type is activity.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if blog section content type is trip types.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_content_type]' )->value();
	return mega_tour_pro_is_blog_section_enable( $control ) && ( 'destination' == $content_type );
}
/**
 * Check if testimonial panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_content_type]' )->value();
	return mega_tour_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_content_type]' )->value();
	return mega_tour_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_content_type]' )->value();
	return mega_tour_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_content_type]' )->value();
	return mega_tour_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is author.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_testimonial_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[testimonial_content_type]' )->value();
	return mega_tour_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}
/**
 * Check if subscription panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_subscription_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout || 'third-design' == $home_layout )  ;
}
/**
 * Check if subscription section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[subscription_section_enable]' )->value() );
}
/**
 * Check if subscription section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_subscription_business_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return (mega_tour_pro_is_subscription_section_enable($control) && ($home_layout == 'third-design'));
}

/**
 * Check if cta panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_cta_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}
/**
 * Check if call to action section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if call to action section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_section_enable]' )->value() && ('custom' == $content_type) );
}
/**
 * Check if call to action section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_section_enable]' )->value() && ('post' == $content_type) );
}
/**
 * Check if call to action section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[cta_section_enable]' )->value() && ('page' == $content_type) );
}
/**
 * Check if partner panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('default-design' == $home_layout || 'second-design' == $home_layout )  ;
}
/**
 * Check if Partners section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_section_enable]' )->value() );
}
/**
 * Check if Partners section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_content_type]' )->value();
	return mega_tour_pro_is_partner_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if partner section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_content_type]' )->value();
	return mega_tour_pro_is_partner_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if partner section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_content_type]' )->value();
	return mega_tour_pro_is_partner_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if partner section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_content_type]' )->value();
	return mega_tour_pro_is_partner_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if partner section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_partner_section_content_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[partner_content_type]' )->value();
	return mega_tour_pro_is_partner_section_enable( $control ) && ( 'category' != $content_type );
}


/**
 * Check if Blog featured panel Disable
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_tour_pro_theme_options[home_layout]' )->value();
	return ('fourth-design' == $home_layout )  ;
}

/**
 * Check if  Blog featured section is enabled.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_featured_section_enable]' )->value() );
}
/**
 * Check if  Blog featured section content type is category.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_featured_content_type]' )->value();
	return mega_tour_pro_is_blog_featured_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if  Blog featured section content type is page.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_featured_content_type]' )->value();
	return mega_tour_pro_is_blog_featured_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if  Blog featured section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_featured_content_type]' )->value();
	return mega_tour_pro_is_blog_featured_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if  Blog featured section content type is post.
 *
 * @since Mega Tour Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_pro_is_blog_featured_section_content_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_pro_theme_options[blog_featured_content_type]' )->value();
	return mega_tour_pro_is_blog_featured_section_enable( $control ) && ( 'category' != $content_type );
}