<?php
/**
 * Blog Featured Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Blog Featured section
$wp_customize->add_section( 'mega_tour_pro_blog_featured_section', array(
	'title'             => esc_html__( 'Blog Featured ','mega-tour-pro' ),
	'description'       => esc_html__( 'Blog Featured Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_blog_featured_panel_enable',
) );

// Blog Featured content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_featured_section_enable]', array(
	'default'			=> 	$options['blog_featured_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[blog_featured_section_enable]', array(
	'label'             => esc_html__( 'Blog Featured Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_featured_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// Blog Featured content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_featured_content_type]', array(
	'default'          	=> $options['blog_featured_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_blog_featured_section_enable',
	'choices'			=> array(
        'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
        'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
        'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
    )
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_blog_section_enable',
	'choices'			=> mega_tour_pro_blog_content_type(),
) );

// Blog Featured post number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_featured_count]', array(
	'default'          	=> $options['blog_featured_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_blog_featured_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_featured_section',
	'active_callback'   => 'mega_tour_pro_is_blog_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );
for ( $i = 1; $i <= $options['blog_featured_count']; $i++ ) :

	// Blog Featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[blog_featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_blog_featured_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_blog_featured_section_content_page_enable',
	) ) );

	// Blog Featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[blog_featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_blog_featured_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_blog_featured_section_content_post_enable',
	) ) );

endfor;

// Blog Featured Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_category_enable'
) ) );