<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'mega_tour_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','mega-tour-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_featured_panel_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_featured_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// Featured sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_sub_title]', array(
    'default'           => $options['featured_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_featured_section',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'text',
) );


// Featured title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_featured_section',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[featured_title]', array(
		'selector'            => '#featured-packages .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_featured_title_partial',
    ) );
}

// Featured btn title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_btn_title]', array(
	'default'			=> $options['featured_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_btn_title]', array(
	'label'           	=> esc_html__( 'Read More Text', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_featured_section',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[featured_btn_title]', array(
		'selector'            => '#featured-packages .section-header-wrapper .read-more a.btn',
		'settings'            => 'mega_tour_pro_theme_options[featured_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_featured_btn_title_partial',
    ) );
}
// featured btn link setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_btn_link]', array(
	'label'           	=> esc_html__( 'Read more Link', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_featured_section',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'url',
	) );

// Featured post  number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_featured_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_featured_section',
	'active_callback'   => 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'choices'			=> mega_tour_pro_featured_content_type(),
) );

// Featured category image enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_cat_meta_image_enable]', array(
	'default'			=> 	$options['featured_cat_meta_image_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[featured_cat_meta_image_enable]', array(
	'label'             => esc_html__( 'Use Category Meta Image', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: You can enable background image from category image for featured, Destinations, Activities and Trip Types.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_featured_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
	'active_callback'   => 'mega_tour_pro_is_featured_cat_meta_section_enable',
) ) );


for ( $i=1; $i <= $options['featured_count']; $i++ ) { 

	// Featured image enable control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_background_image_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[featured_background_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'mega-tour-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 500, 500 ),
			'section'     		=> 'mega_tour_pro_featured_section',
			'active_callback'	=> 'mega_tour_pro_is_featured_section_image_enable',
	) ) );
	

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'mega_tour_pro_theme_options[featured_content_category_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[featured_content_category_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select category %d', 'mega-tour-pro' ), $i ),
		'description'      	=> esc_html__( 'Note: Featured selected no of posts will be shown from selected category', 'mega-tour-pro' ),
		'section'           => 'mega_tour_pro_featured_section',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'mega_tour_pro_is_featured_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'mega_tour_pro_theme_options[featured_content_trip_types_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[featured_content_trip_types_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip Types %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_featured_section',
		'taxonomy'			=> 'itinerary_types',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'mega_tour_pro_is_featured_section_content_trip_types_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'mega_tour_pro_theme_options[featured_content_activity_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[featured_content_activity_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Activity %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_featured_section',
		'taxonomy'			=> 'activity',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'mega_tour_pro_is_featured_section_content_activity_enable'
	) ) );

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'mega_tour_pro_theme_options[featured_content_destination_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[featured_content_destination_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Destination %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_featured_section',
		'taxonomy'			=> 'travel_locations',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'mega_tour_pro_is_featured_section_content_destination_enable'
	) ) );

	$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_tour_pro_theme_options[featured_hr_'. $i .']',
		array(
			'section'         => 'mega_tour_pro_featured_section',
			'type'			  => 'hr'
	) ) );

}

//featured read more_btn_title
$wp_customize->add_setting( 'mega_tour_pro_theme_options[featured_read_more_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_read_more_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[featured_read_more_btn_title]', array(
	'label'           	=> esc_html__( 'Featured Post Read More Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_featured_section',
	'active_callback' 	=> 'mega_tour_pro_is_featured_section_enable',
	'type'				=> 'text',
) );
