<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'mega_tour_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','mega-tour-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_subscription_panel_enable',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_subscription_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// subscription sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_subscription_section',
	'active_callback' 	=> 'mega_tour_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now .section-header p.section-subtitle',
		'settings'            => 'mega_tour_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_subscription_section',
	'active_callback' 	=> 'mega_tour_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_subscription_title_partial',
    ) );
}
// subscription  background image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_bg_image]', array(
	'default'           =>$options['subscription_bg_image'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[subscription_bg_image]',
		array(
		'label'       		=> esc_html__( 'subscription Background Image', 'mega-tour-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 1920, 600 ),
		'section'     		=> 'mega_tour_pro_subscription_section',
		'active_callback'	=> 'mega_tour_pro_is_subscription_section_enable',
) ) );

// subscription Business background image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_business_bg_image]', array(
	'default'           =>$options['subscription_business_bg_image'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[subscription_business_bg_image]',
		array(
		'label'       		=> esc_html__( 'Subscription Background Image', 'mega-tour-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 1920, 600 ),
		'section'     		=> 'mega_tour_pro_subscription_section',
		'active_callback'	=> 'mega_tour_pro_is_subscription_business_section_enable',
) ) );

// subscription description setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_description]', array(
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[subscription_description]', array(
	'label'           	=> esc_html__( 'Description', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_subscription_section',
	'active_callback' 	=> 'mega_tour_pro_is_subscription_section_enable',
	'type'				=> 'textarea',
) );

// subscription btn title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_subscription_section',
	'active_callback' 	=> 'mega_tour_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

