<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_service_section() {
        $options = mega_tour_pro_get_theme_options();

        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'mega_tour_pro_section_status', true, 'service_section_enable' );

        if($options['home_layout'] == 'fourth-design'){
            $service_enable = false;
        }

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        switch ( $options['home_layout'] ) {
            case 'default-design':
                // Render Default service section now.
                mega_tour_pro_render_service_section( $section_details );
                break;
            
            case 'third-design':
                // Render Business service section now.
                mega_tour_pro_render_business_service_section( $section_details );
                break;
            
            default:
                // Render Default service section now.
                mega_tour_pro_render_service_section( $section_details );
        }

    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_service_section_details' ) ) :
    /**
    * Service section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input service section details.
    */
    function mega_tour_pro_get_service_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

       
        $service_content_type  = $options['service_content_type'];  // Content type.
        $service_count  = ! empty( $options['service_count'] ) ? $options['service_count'] : 3; // Service Post Count
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $service_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

			case 'trip-types': // trip-types
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['service_content_trip_types'] ) ? $options['service_content_trip_types'] : array();

				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'itinerary_types',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $service_count ),
					);
			break;

			
			case 'destination': //Destination
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['service_content_destination'] ) ? $options['service_content_destination'] : array();
				
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'travel_locations',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $service_count ),
					); 
			break;

			case 'activity':
				if ( ! class_exists( 'WP_Travel' ) )
					return;
				
				$cat_id = ! empty( $options['service_content_activity'] ) ? $options['service_content_activity'] : array();
                if ( empty( $cat_id ) )
                    return;
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'activity',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $service_count ),
					); 
			break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_tour_pro_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif
;
// service section content details.
add_filter( 'mega_tour_pro_filter_service_section_details', 'mega_tour_pro_get_service_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_service_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();

        $trip_search_title = isset($trip_search_title) ? $options['trip_search_title'] : esc_html__('Search Destination','mega-tour-pro');
        $service_btn_label = isset($service_btn_label) ? $options['service_btn_label'] : esc_html__('Learn More','mega-tour-pro');

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="our-services" class="relative page-section">
                <div class="wrapper">
                    <div class="section-content clear col-3">

                        <?php foreach ($content_details as $content) : ?>
                        <article>
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title'])?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->

                                <a href="<?php echo esc_url($content['url']); ?>" class="more-link"><span><?php echo esc_html($service_btn_label); ?></span>
                                   <?php echo mega_tour_pro_get_svg(array('icon'=>'right')); ?>
                                </a><!-- .more-link -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->

                <?php if($options['trip_search_enable'] &&  class_exists( 'WP_Travel' )): ?>
                    <div class="wrapper travel-search-wrapper">
                        <div id="travel-search-section" class="relative page-section">
                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html($trip_search_title); ?></h2>
                            </header>
                            <div class="wp-travel-filter">
                                <?php mega_tour_pro_wptravel_search_form(); ?>
                            </div><!-- wp-travel-filter -->
                        </div><!-- #travel-search-section -->
                    </div><!-- .wrapper -->
                <?php endif; ?>

            </div><!-- #our-services -->

    <?php }
endif;

if ( ! function_exists( 'mega_tour_pro_render_business_service_section' ) ) :
  /**
   * Start Business service section
   *
   * @return string Business service content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_business_service_section( $content_details = array() ) {
        $options = mega_tour_pro_get_theme_options();

        $service_title          = isset($options['service_title']) ? $options['service_title'] : esc_html__('Make Successful Business','mega-tour-pro');
        $service_description    = isset( $options['service_description']) ? $options['service_description'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="business-services" class="relative page-section">
            <div class="wrapper">
                <div class="business-section-header">
                    <h2 class="business-section-title"><?php echo esc_html($service_title); ?></h2>
                    <p class="business-section-subtitle"><?php echo esc_html($service_description); ?></p>
                </div><!-- .business-section-header -->

                <div class="business-section-content clear col-3">

                <?php foreach ($content_details as $i => $content) : 
                    $icon = isset( $options['service_content_icon_' . ($i+1) . '']) ? $options['service_content_icon_' . ($i+1) . ''] : '';
                    ?>
                    <article>
                        <div class="business-service-item">
                            <div class="business-service-icon">

                                <?php if(!empty($icon)): ?>
                                    <a href="<?php echo esc_url($content['url']); ?>"><i class="fa <?php echo esc_attr($icon)?>"></i></a>
                                <?php endif; ?>

                            </div><!-- .business-service-icon -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title'])?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .business-service-item -->
                    </article>
                <?php endforeach; ?>
                
                </div><!-- .business-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #business-services -->

    <?php }
endif;